<?php
/*
Plugin Name: CSS Accordion
Version: 4.02
Plugin URI: https://nhws.localinfo.jp/
Description: Adds an accordion-like stretching effect. Write tags like [accordion label="abc" group="xyz" opened]contents[/accordion]
Author: ぴー＠西東京 / peaonmob
Author URI: https://nhws.localinfo.jp/
*/


add_filter('init', 'plugin_bbcode_cssaccordion');
add_action('wp_head', 'plugin_accordion_head');


function plugin_bbcode_cssaccordion() {
	$bbcode = plugin_bbcode_init(); //import the "global" bbcode object into current function
								// this way 
								// a) parsing is done only once, and by the official plugin
								// b) you create only ONE object, and therefore computation is quicker
	$bbcode->addCode (
		'accordion',  // tag name: this will go between square brackets
		'callback_replace', // type of action: we'll use a callback function
		'plugin_custombbcode_accordion', // name of the callback function
		array ('usecontent_param' => array ('default')), // supported parameters: "default" is [inc=valore]
		'inline', // type of the tag, inline or block, etc
		array ('listitem', 'block', 'inline', 'link'), // type of elements in which you can use this tag
		array ()); // type of elements where this tag CAN'T go (in this case, none, so it can go everywhere)
	$bbcode->setCodeFlag ('accordion', 'closetag', BBCODE_CLOSETAG_MUSTEXIST); // a closing tag is mandatory [/tag]
}


function plugin_custombbcode_accordion($action, $attributes, $content, $params, $node_object) {
	$accordionconf = plugin_getoptions('cssaccordion');	//設定の読み出し
	$lang = lang_load('plugin:cssaccordion');	// 多言語対応
	$accordion['label'] = isset($attributes['label']) ? htmlentities($attributes['label']) : (
		isset($accordionconf['label']) ? $accordionconf['label'] : $lang['plugin']['accordion']['label']
	);
	$accordiontype = isset($attributes['group']) ? (
		(isset($accordionconf['closeable']) && $accordionconf['closeable'] == 'checked') ? 
			'class="ac-toggle ac-radio" type="radio" name="'.$attributes['group'].'"' : 
			'class="ac-toggle" type="radio" name="'.$attributes['group'].'"'
	) : 'class="ac-toggle" type="checkbox"';
	$accordionid = uniqid();
	$allowed_tags = ['a','b','br','em','hr','i','img','li','ol','p','s','span','strong','u','ul'];
	$accordionchecked = isset($attributes['opened']) ? ' checked' : '';
	return '<div><input id="'.$accordionid.'" '.$accordiontype.$accordionchecked.'>'
	.'<label class="ac-title" for="'.$accordionid.'"><a>'.$accordion['label'].'</a></label>'
	.'<div class="ac-content">'.strip_tags($content ?? '', $allowed_tags).'</div></div>';
}


function plugin_accordion_head() {
	$accordionconf = plugin_getoptions('cssaccordion');	//設定の読み出し
//	$lang = lang_load('plugin:cssaccordion');	// 多言語対応
	$delay = isset($accordionconf['delay']) ? $accordionconf['delay'] : 15;
	$tbgc = isset($accordionconf['tbgc']) ? $accordionconf['tbgc'] : 'eeeeee';
	$pdir = plugin_geturl('cssaccordion');
	echo <<<ACCORDIONHEAD
\n	<!-- start of NHWS CSS Accordion -->
	<link rel="stylesheet" type="text/css" href="{$pdir}res/css_accordion.css.php?delay={$delay}&tbgc={$tbgc}">
	<script src="{$pdir}res/css_accordion.js"></script>
	<!-- end of NHWS CSS Accordion -->\n
ACCORDIONHEAD;
}


if (class_exists('AdminPanelAction')){
	/*
	Provides an admin panel entry for CSS Accordion setup.
	*/
	class admin_plugin_cssaccordion extends AdminPanelAction {
//		var $langres = 'plugin:cssaccordion';
		/*
		Initializes this panel.
		*/
		function setup() {
			$this->smarty->assign('admin_resource', "plugin:cssaccordion/admin.plugin.cssaccordion");
		}
		/*
		Setups the default panel.
		*/
		function main() {
			$accordionconf = plugin_getoptions('cssaccordion');	//設定の読み出し
			$lang = lang_load('plugin:cssaccordion');	// 多言語対応
			$accordionconf['label'] =
			 isset($accordionconf['label']) ? $accordionconf['label'] : $lang['plugin']['accordion']['label'];
			$accordionconf['delay'] =
			 isset($accordionconf['delay']) ? $accordionconf['delay'] : 15;
			$accordionconf['closeable'] =
			 isset($accordionconf['closeable']) ? $accordionconf['closeable'] : 'checked';
			$accordionconf['tbgc'] =
			 isset($accordionconf['tbgc']) ? $accordionconf['tbgc'] : 'eeeeee';
			$this->smarty->assign('accordionconf', $accordionconf);
		}
		/*
		Will be executed when the FontSizeSelect configuration is send.
		@return int
		*/
		function onsubmit($data = null) {
			global $fp_config;
			if (isset($_POST['label']) && isset($_POST['delay']) && isset($_POST['tbgc'])) {
				if ($_POST['delay'] < 5 || $_POST['delay'] > 50){
					$_POST['delay'] = 15;
				}
				$_POST['closeable'] = ($_POST['closeable'] == 'on') ? 'checked' : '';
				$_POST['tbgc'] = (is_color_code($_POST['tbgc'])) ? 
					str_replace('#', '', $_POST['tbgc']) : 'eeeeee';
				plugin_addoption('cssaccordion', 'label', htmlentities($_POST['label']));
				plugin_addoption('cssaccordion', 'delay', htmlentities($_POST['delay']));
				plugin_addoption('cssaccordion', 'closeable', htmlentities($_POST['closeable']));
				plugin_addoption('cssaccordion', 'tbgc', htmlentities($_POST['tbgc']));
				plugin_saveoptions('cssaccordion');
				$this->smarty->assign('success', 1);
			} else {
				$this->smarty->assign('success', -1);
			}
			return 2;
		}
	}
	admin_addpanelaction('plugin', 'cssaccordion', true);
}


function is_color_code( $color ){
  if( preg_match( "/^#([a-fA-F0-9]{6}|[a-fA-F0-9]{3})$/", $color ) ){
    return true;
  }else{
    return false;
  }
}


?>
